@@ -161,8 +161,9 @@ connect() creates a connection to a mysql server.
 */
 bool CMySQL::connect()
 {
+
 #ifdef DEBUG
-  qDebug("CMySQL::connect()");
+		qDebug("CMySQL::connect()");
 #endif  
 
   char init_command[100];
@@ -214,7 +215,8 @@ bool CMySQL::connect()
   }
   else
 #endif  
-    mysql_unix_socket = QString::null;  
+    mysql_unix_socket = QString::null;
+    mysql_init(mysql);
   if (!mysql_real_connect(mysql, mysql_host, mysql_user, mysql_passwd, mysql_db, mysql_port, mysql_unix_socket, mysql_client_flags))
   {
     disconnect(false);
@@ -448,16 +450,26 @@ bool CMySQL::mysqlShutdown()
   qDebug("CMySQL::mysqlShutdown()");
 #endif
   
-  if (!isConnected())
-    return false;
-  
-  if (mysql_shutdown(mysql) != 0)
-  {
-    if (emiterror)
-      emitError();
-    return false;
-  }
-  return true;
+	if (!isConnected()){
+		return false;
+	}
+	
+#ifdef SHUTDOWN_DEFAULT
+	if (mysql_shutdown(mysql,SHUTDOWN_DEFAULT) != 0)
+	{
+	if (emiterror)
+		emitError();
+		return false;
+	}
+#else
+	if (mysql_shutdown(mysql,SHUTDOWN_DEFAULT) != 0)
+	{
+	if (emiterror)
+		emitError();
+		return false;
+	}
+#endif
+	return true;
 }
 
 /*
