@@ -992,8 +992,6 @@ void CGeneralAppConfigTab::languageChange()
   saveWorkspace->setText(tr("Restore last Workspace on startup"));
   QWhatsThis::add(saveWorkspace, tr("When enabled, the application will restore the last Workspace of the previous execution by automatically opening all windows and connections which where open prior shutdown."));
   language->clear();
-  language->insertItem(tr("Item1"));
-  language->insertItem(tr("New Item2"));
   QWhatsThis::add(language, tr("This will change the display Language of the Application.  If changed, one will have to restart the application for changes to take place."));
   languageLabel->setText(tr("Language"));
   historyNumberLabel->setText(tr("History size for Queries"));
