@@ -27,6 +27,10 @@
 #include <qregexp.h>
 #include <qtranslator.h>
 
+#ifdef QT_OSX_BUILD
+#include <CoreServices/CoreServices.h>
+#endif
+
 #ifdef DEBUG_LEVEL
 #if DEBUG_LEVEL < 4
 #undef DEBUG
@@ -84,10 +88,31 @@ void CApplication::initGlobals(bool startup)
   
   CConfig *cfg = new CConfig();
 
+#ifdef QT_OSX_BUILD
+  CFBundleRef appBundle = CFBundleGetMainBundle (); // No need to release this
+  CFURLRef resourcesURL = CFBundleCopyResourcesDirectoryURL (appBundle); // must release this
+  CFURLRef absoluteURL = CFURLCopyAbsoluteURL (resourcesURL); // must release
+  CFStringRef pathref = CFURLCopyFileSystemPath ( absoluteURL , kCFURLPOSIXPathStyle ); // must release
+  int strsize = 1024;
+  char * pathstr = (char *)malloc(strsize);
+  //CFShow(pathref);
+  while (!CFStringGetCString(pathref, pathstr, strsize, kCFStringEncodingUTF8))
+  {
+  	strsize += 1024;
+	  pathstr = (char *)realloc(pathstr, strsize);
+  }
+  QString mydir = pathstr;
+  free(pathstr);
+  CFRelease(pathref);
+  CFRelease(resourcesURL);
+  CFRelease(absoluteURL);
+  mydir += "/";
+#else
   //Directory where mysqlcc.exe (or mysqlcc) is.
-  QString mydir = QDir::currentDirPath() + "/";
-  //QString mydir = "/usr/share/mysqlcc/";  This needs to be done with a PREFIX define ..
-  
+  //QString mydir = QDir::currentDirPath() + "/";
+  QString mydir = "/usr/share/mysqlcc/";  // This needs to be done with a PREFIX define ..
+#endif
+
   //Translations path
   translations_path = cfg->readStringEntry("Translations Path", mydir + "translations/");  
 
@@ -168,7 +193,7 @@ void CApplication::initGlobals(bool startup)
   default_connection_name = cfg->readStringEntry("Default Connection Name", QString::null);
 
   //Style
-  current_style = cfg->readStringEntry("Style", "Windows");
+  current_style = cfg->readStringEntry("Style", "MotifPlus");
   setStyle(current_style);
   setStylePalette(current_style);
   
