@@ -467,8 +467,21 @@ bool CQuerySet::execQuery(const QString &query_str)
           if (explain_rows == 1)
           {
             explain_query->next(true);
-            default_table = explain_query->row(mysql()->mysql()->version().major >= 4 && 
-              mysql()->mysql()->version().minor >= 1 ? 2 : 0);
+//            default_table = explain_query->row(mysql()->mysql()->version().major >= 4 && 
+//              mysql()->mysql()->version().minor >= 1 ? 2 : 0);
+                               // NetVicious modification
+                               if ( mysql()->mysql()->version().major == 5 )
+                               {
+                                       default_table = explain_query->row(2);
+                               }
+                               else
+                               {
+               default_table = explain_query->row(mysql()->mysql()->version().major >= 4 &&
+                       mysql()->mysql()->version().minor >= 1 ? 2 : 0);
+                               }
+                               // End NetVicious modification
+
+
             if (!default_table.isEmpty())
             {
               finished_evt->read_only = default_database.isEmpty() || 
@@ -1307,6 +1320,7 @@ void CQueryWindow::setTable(const QString &s)
     q->setDefaultTable(s);
 }
 
+
 void CQueryWindow::newWindowFromTab()
 {
   CQuerySet *q = currentQuerySet();
@@ -1931,7 +1945,7 @@ void CQueryWindow::newQueryWindow(const QString &query_str, const QString &datab
   if (!database.isEmpty())
     w->setDatabase(database);
   if (!table.isEmpty())
-    w->setTable(table);  
+    w->setTable(table);
   if (!query_str.isEmpty())
     w->doExecuteQuery(query_str);  
 }
