@@ -18,6 +18,7 @@
 #include "CRegisterServerDialog.h"
 #include "globals.h"
 #include "CMySQLServer.h"
+#include "CMySQLQuery.h"
 #include "CConsoleWindow.h"
 #include "CDatabaseListView.h"
 #include "CConfig.h"
@@ -76,7 +77,7 @@ CMySQLOptionsTab::CMySQLOptionsTab(QWidget* parent, const char* name, WFlags fl)
   selectLimit->setMaxValue(0xFFFFFF);
   selectLimit->setMinValue(0);
   selectLimit->setSpecialValueText(tr("Unlimited"));
-  selectLimit->setValue(1000);
+  selectLimit->setValue(0);
   
   CMySQLOptionsTabLayout->addMultiCellWidget(selectLimit, 1, 1, 1, 2);
   
@@ -93,8 +94,9 @@ CMySQLOptionsTab::CMySQLOptionsTab(QWidget* parent, const char* name, WFlags fl)
   
   maxJoinSize = new QSpinBox(this, "maxJoinSize");
   maxJoinSize->setMaxValue(0xFFFFFF);
-  maxJoinSize->setMinValue(1);
-  maxJoinSize->setValue(1000000);  
+  maxJoinSize->setMinValue(0);
+  maxJoinSize->setSpecialValueText(tr("Unlimited"));
+  maxJoinSize->setValue(0);  
   
   CMySQLOptionsTabLayout->addMultiCellWidget(maxJoinSize, 4, 4, 1, 2);
   
@@ -154,9 +156,9 @@ bool CMySQLOptionsTab::save(CConfig *conn)
 void CMySQLOptionsTab::setDefaultValues(CConfig *Settings)
 {
   connectTimeout->setValue(Settings->readNumberEntry("Timeout", 0));
-  selectLimit->setValue(Settings->readNumberEntry("Limit Select Queries Number", 1000));
+  selectLimit->setValue(Settings->readNumberEntry("Limit Select Queries Number", 0));
   netBufferLength->setValue(Settings->readNumberEntry("Net Buffer Length", 16384));
-  maxJoinSize->setValue(Settings->readNumberEntry("Max Join Size", 1000000L));
+  maxJoinSize->setValue(Settings->readNumberEntry("Max Join Size", 0));
   maxAllowedPacket->setValue(Settings->readNumberEntry("Max Allowed Packet", 16*1024L*1024L));
   localInFile->setChecked(strtobool(Settings->readStringEntry("Allow Local Infile")));
 }
@@ -237,7 +239,7 @@ CSaveServerOptionsTab::CSaveServerOptionsTab(QWidget * parent, const char *name,
   TextLabel4->setMargin(3);
   TextLabel4->setText(tr("You can use the following escaped symbols to represent certain escaped characters:<br>\n"
     "<b>\\n</b>    New Line<br>\n"
-    "<b>\\r</b>     Carriege Return<br>\n"
+    "<b>\\r</b>     Carriage Return<br>\n"
     "<b>\\t</b>     Tab"));
   TextLabel4->setAlignment(int(QLabel::WordBreak | QLabel::AlignTop));
   CSaveServerOptionsTabLayout->addWidget(TextLabel4);
@@ -604,8 +606,13 @@ CGeneralServerOptionsTab::CGeneralServerOptionsTab(bool isediting, QWidget * par
   defaultServer->setChecked(myApp()->consoleWindow()->databaseListView()->childCount() == 0);
   
   CGeneralServerOptionsTabLayout->addMultiCellWidget(defaultServer, 7, 7, 0, 3);
+
+  disableStartupConnect = new QCheckBox(this, "disableStartupConnect");
+  disableStartupConnect->setChecked(false);
+  CGeneralServerOptionsTabLayout->addMultiCellWidget(disableStartupConnect, 8, 8, 0, 3);
+
   QSpacerItem* spacer_3 = new QSpacerItem(20, 160, QSizePolicy::Minimum, QSizePolicy::Expanding);
-  CGeneralServerOptionsTabLayout->addItem(spacer_3, 8, 3);
+  CGeneralServerOptionsTabLayout->addItem(spacer_3, 9, 3);
   languageChange();
   clearWState(WState_Polished);
 
@@ -614,7 +621,8 @@ CGeneralServerOptionsTab::CGeneralServerOptionsTab(bool isediting, QWidget * par
   setTabOrder(UserNameBox, PasswordBox);
   setTabOrder(PasswordBox, PortBox);
   setTabOrder(PortBox, retrieveShowTableStatus);
-  setTabOrder(retrieveShowTableStatus, compressCheckBox);
+  setTabOrder(retrieveShowTableStatus, retrieveShowTables);
+  setTabOrder(retrieveShowTables, compressCheckBox);
   setTabOrder(compressCheckBox, blockingCheckBox);
   setTabOrder(blockingCheckBox, enableCompletionCheckBox);
   setTabOrder(enableCompletionCheckBox, promptPasswordCheckBox);
@@ -623,7 +631,7 @@ CGeneralServerOptionsTab::CGeneralServerOptionsTab(bool isediting, QWidget * par
   setTabOrder(SSLCheckBox, socketFile);
   setTabOrder(socketFile, socketBrowse);
   setTabOrder(socketBrowse, defaultServer);
-  setTabOrder(defaultServer, retrieveShowTables);
+  setTabOrder(defaultServer, disableStartupConnect);
   init();
 }
 
@@ -664,6 +672,8 @@ void CGeneralServerOptionsTab::languageChange()
   QWhatsThis::add(promptPasswordCheckBox, tr("When enabled, a Password Dialog will appear before a connection to the Server is attempted.  This is useful for when you don't want to store your password in the settings file."));
   defaultServer->setText(tr("Make this server the Default Connection"));
   QWhatsThis::add(defaultServer, tr("When checked, this server will be used as the default server for command line parameters."));
+  disableStartupConnect->setText(tr("Never automatically connect to this server on startup"));
+  QWhatsThis::add(disableStartupConnect, tr("When checked, MySQLCC will not automatically connect to this server on startup."));
 }
 
 
@@ -686,6 +696,7 @@ void CGeneralServerOptionsTab::setDefaultValues(CConfig *Settings)
   oneConnectionCheckBox->setChecked(strtobool(Settings->readStringEntry("One Connection")));
   enableCompletionCheckBox->setChecked(strtobool(Settings->readStringEntry("Completion")));
   SSLCheckBox->setChecked(strtobool(Settings->readStringEntry("SSL")));
+  disableStartupConnect->setChecked(strtobool(Settings->readStringEntry("Disable Startup Connect", "false")));
 
   bool r = strtobool(Settings->readStringEntry("Retrieve Method", "true"));
   retrieveShowTableStatus->setChecked(r);
@@ -752,6 +763,7 @@ bool CGeneralServerOptionsTab::save(CConfig *conn)
   ret &= conn->writeEntry("Completion", booltostr(enableCompletionCheckBox->isChecked()));
   ret &= conn->writeEntry("SSL", booltostr(SSLCheckBox->isChecked()));
   ret &= conn->writeEntry("Retrieve Method", booltostr(retrieveShowTableStatus->isChecked()));
+  ret &= conn->writeEntry("Disable Startup Connect", booltostr(disableStartupConnect->isChecked()));
 
 #ifndef WIN32
   ret &= conn->writeEntry("Socket", socketFile->text().stripWhiteSpace());
@@ -806,13 +818,14 @@ void CRegisterServerDialog::initConnectionDialog(CMessagePanel *messagepanel)
 #ifdef DEBUG
   qDebug("CRegisterServerDialog::initConnectionDialog()");
 #endif
-  
-  myApp()->incCritical();  
+    
+  myApp()->incCritical();
   messagePanel = messagepanel;
   GeneralServerOptionsTab = new CGeneralServerOptionsTab(isEditing, tab(), "General");
   insertTab(GeneralServerOptionsTab);
   insertTab(new CMySQLOptionsTab(tab()));
-  insertTab(new CDatabaseServerOptionsTab(tab()));
+  CDatabaseServerOptionsTab *databaseServerOptionsTab = new CDatabaseServerOptionsTab(tab());
+  insertTab(databaseServerOptionsTab);
   insertTab(new CSaveServerOptionsTab(tab()));
   customButton->setText(tr("&Test"));
   customButton->setIconSet(getPixmapIcon("pingIcon"));
@@ -827,6 +840,22 @@ void CRegisterServerDialog::initConnectionDialog(CMessagePanel *messagepanel)
     delete Settings;    
     okPushButton->setText(tr("&Apply"));
     QWhatsThis::add(okPushButton, tr("Click to Apply changes to this connection."));
+    if (databaseServerOptionsTab->databases->count() == 0)
+    {
+      CMySQLServer tmp(cfgname);
+      if (tmp.connect())
+      {
+        CMySQLQuery q(tmp.mysql());
+        q.setEmitErrors(false);
+        q.setEmitMessages(false);
+        QPixmap databaseIcon = getPixmapIcon("databaseDisconnectedIcon"); 
+        if (q.exec("SHOW databases"))
+        {
+          while (q.next())
+            databaseServerOptionsTab->databases->insertItem(databaseIcon, q.row(0));
+        }
+      }
+    }
   }
   else
   {
@@ -870,10 +899,9 @@ void CRegisterServerDialog::testConnection()
     CMySQLServer *testConn = new CMySQLServer(tmpConnectionName);
     testConn->setPrintConnectionName(false);
     if (testConn->connect())
-    {
       testConn->showMessage(INFORMATION, tr("Connection Successful."));
-      this->show();
-    }
+    this->show();
+    qApp->processEvents();
     testConn->remove();
     delete testConn;    
   }
