@@ -903,6 +903,7 @@ CFieldProperties::CFieldProperties(QWidget* parent,  const char* name, WFlags fl
     setName("CFieldProperties");
   currentField = 0;
   autoIncField = 0;
+  tableWindow = 0;
   intValidator = new QIntValidator(this);
   intValidator->setBottom(1);  
   floatValidator = new QRegExpValidator(QRegExp("\\d+\\s*,\\s*\\d+"), this);
@@ -1023,6 +1024,12 @@ void CFieldProperties::resetLength(CTableWindowField *f, const QString &t)
   f->Length = ok ? currentField->Length : QString::null;
 }
 
+void CFieldProperties::setHasModified(bool b)
+{
+  if (tableWindow != 0)
+    tableWindow->setHasModified(b);
+}
+
 void CFieldProperties::setFieldType(const QString &t)
 {
   skip = true;
@@ -1119,6 +1126,7 @@ void CFieldProperties::setFieldType(const QString &t)
         currentField->Default = "";
     }
   skip = false;
+  setHasModified(true);
 }
 
 void CFieldProperties::setDefault(const QString &s)
@@ -1127,6 +1135,7 @@ void CFieldProperties::setDefault(const QString &s)
     return;
 
   currentField->Default = Default->isNull() ? QString::null : s;
+  setHasModified(true);
 }
 
 void CFieldProperties::setValue(const QString &s)
@@ -1134,6 +1143,7 @@ void CFieldProperties::setValue(const QString &s)
   if (currentField == 0 || skip)
     return;
   currentField->Value = s;
+  setHasModified(true);  
 }
 
 void CFieldProperties::setLength(const QString &s)
@@ -1141,6 +1151,7 @@ void CFieldProperties::setLength(const QString &s)
   if (currentField == 0 || skip)
     return;
   currentField->Length = s;
+  setHasModified(true);
 }
 
 void CFieldProperties::setUnsigned(bool b)
@@ -1148,6 +1159,7 @@ void CFieldProperties::setUnsigned(bool b)
   if (currentField == 0 || skip)
     return;
   currentField->Unsigned = b;
+  setHasModified(true);
 }
 
 void CFieldProperties::setBinary(bool b)
@@ -1155,6 +1167,7 @@ void CFieldProperties::setBinary(bool b)
   if (currentField == 0 || skip)
     return;
   currentField->Binary = b;
+  setHasModified(true);
 }
 
 void CFieldProperties::setZeroFill(bool b)
@@ -1162,6 +1175,7 @@ void CFieldProperties::setZeroFill(bool b)
   if (currentField == 0 || skip)
     return;
   currentField->ZeroFill = b;
+  setHasModified(true);
 }
 
 void CFieldProperties::setAutoIncrement(bool b)
@@ -1179,7 +1193,8 @@ void CFieldProperties::setAutoIncrement(bool b)
     autoIncField = currentField;
   }
   else  
-    autoIncField = 0;    
+    autoIncField = 0;
+  setHasModified(true);
 }
 
 void CFieldProperties::setField(CTableWindowField *f)
@@ -1238,7 +1253,7 @@ CTableWindow::CTableWindow(QWidget* parent, CMySQLServer *m, const QString &dbna
   tab = new QTabWidget(centralWidget(), "tab");
   tab->setSizePolicy(QSizePolicy((QSizePolicy::SizeType)7, (QSizePolicy::SizeType)1, 0, 0, tab->sizePolicy().hasHeightForWidth()));
   
-  fieldPropertiesTab = new CFieldProperties(tab, "fieldPropertiesTab");
+  fieldPropertiesTab = new CFieldProperties(tab, "fieldPropertiesTab");  
   fieldPropertiesTab->setMessagePanel(messagePanel());
   tab->insertTab(fieldPropertiesTab, trUtf8("Field Properties"));
   
@@ -1397,6 +1412,7 @@ CTableWindow::CTableWindow(QWidget* parent, CMySQLServer *m, const QString &dbna
   }
   skipValueChanged = false;
   myResize(550, 500);
+  fieldPropertiesTab->setTableWindow(this);
 }
 
 
@@ -1592,7 +1608,6 @@ bool CTableWindow::exec(const QString &qry)
 
 QString CTableWindow::getFieldSpecs(CTableWindowField *field, QStringList &dups, bool &ok) const
 {
-  qDebug("CTableWindow::getFieldSpecs()");
   QString sql = QString::null;  
   if (!field->FieldName.isEmpty() && !field->FieldName.isNull())
   {    
@@ -1698,7 +1713,6 @@ QString CTableWindow::getFieldSpecs(CTableWindowField *field, QStringList &dups,
       sql += "AUTO_INCREMENT ";    
   }
   ok = true;
-  qDebug("CTableWindow::getFieldSpecs() - end");
   return sql;
 }
 
@@ -1718,7 +1732,7 @@ bool CTableWindow::alterTable()
   
   sql += indexesTab->getDropIndexes();
   for (QStringList::Iterator it = deletedFields.begin(); it != deletedFields.end(); ++it)
-    sql += "DROP " + *it + ", ";  
+    sql += "DROP " + mysql->mysql()->quote(*it) + ", ";  
 
   QString s;
   for (int i = 0; i < fields->numRows(); i++)
@@ -1837,10 +1851,7 @@ bool CTableWindow::save()
       tblName = QInputDialog::getText(tr("Table Name"), tr("Please enter the Table Name"), QLineEdit::Normal, QString::null, &ok);
       tblName = tblName.stripWhiteSpace();
       if (!ok || tblName.isEmpty())
-      {
-        qDebug("CTableWindow::save() error !ok || tblName.isEmpty()");
         return false;
-      }
       else
         tablePropertiesTab->tableName->setText(tblName);
     }
@@ -1891,6 +1902,9 @@ void CTableWindow::saveAs()
 
 void CTableWindow::currentChanged(int row, int)
 {
+  if( !fields->item(row,2)) /* currentChanged() is called when new, null row is inserted */
+    return;
+  
   CTableWindowField *f = ((CTableWindowComboItem *)fields->item(row, 2))->Field;
   if (f->Type.isNull())
     f->Type = fields->text(row, 2);
